@@ -2,37 +2,43 @@
 #' @name check_collinearity
 #'
 #' @description
+#' `check_collinearity()` checks regression models for multicollinearity by
+#' calculating the (generalized) variance inflation factor (VIF, Fox & Monette
+#' 1992). `multicollinearity()` is an alias for `check_collinearity()`.
+#' `check_concurvity()` is a wrapper around `mgcv::concurvity()`, and can be
+#' considered as a collinearity check for smooth terms in GAMs. Confidence
+#' intervals for VIF and tolerance are based on Marcoulides et al. (2019,
+#' Appendix B).
 #'
-#'  `check_collinearity()` checks regression models for
-#'  multicollinearity by calculating the variance inflation factor (VIF).
-#'  `multicollinearity()` is an alias for `check_collinearity()`.
-#'  `check_concurvity()` is a wrapper around `mgcv::concurvity()`, and can be
-#'  considered as a collinearity check for smooth terms in GAMs. Confidence
-#'  intervals for VIF and tolerance are based on Marcoulides et al.
-#'  (2019, Appendix B).
-#'
-#' @param x A model object (that should at least respond to `vcov()`,
-#'  and if possible, also to `model.matrix()` - however, it also should
-#'  work without `model.matrix()`).
+#' @param x A model object (that should at least respond to `vcov()`, and if
+#' possible, also to `model.matrix()` - however, it also should work without
+#' `model.matrix()`).
 #' @param component For models with zero-inflation component, multicollinearity
-#'  can be checked for the conditional model (count component,
-#'  `component = "conditional"` or `component = "count"`),
-#'  zero-inflation component (`component = "zero_inflated"` or
-#'  `component = "zi"`) or both components (`component = "all"`).
-#'  Following model-classes are currently supported: `hurdle`,
-#'  `zeroinfl`, `zerocount`, `MixMod` and `glmmTMB`.
+#' can be checked for the conditional model (count component, `component =
+#' "conditional"` or `component = "count"`), zero-inflation component
+#' (`component = "zero_inflated"` or `component = "zi"`) or both components
+#' (`component = "all"`). Following model-classes are currently supported:
+#' `hurdle`, `zeroinfl`, `zerocount`, `MixMod` and `glmmTMB`.
 #' @param ci Confidence Interval (CI) level for VIF and tolerance values.
 #' @param verbose Toggle off warnings or messages.
 #' @param ... Currently not used.
 #'
 #' @return A data frame with information about name of the model term, the
-#'   variance inflation factor and associated confidence intervals, the factor
-#'   by which the standard error is increased due to possible correlation
-#'   with other terms, and tolerance values (including confidence intervals),
-#'   where `tolerance = 1/vif`.
+#' (generalized) variance inflation factor and associated confidence intervals,
+#' the adjusted VIF, which is the factor by which the standard error is
+#' increased due to possible correlation with other terms (inflation due to
+#' collinearity), and tolerance values (including confidence intervals), where
+#' `tolerance = 1/vif`.
 #'
 #' @seealso [`see::plot.see_check_collinearity()`] for options to customize the plot.
 #'
+#' @details
+#' `check_collinearity()` calculates the generalized variance inflation factor
+#' (Fox & Monette 1992), which also returns valid results for categorical
+#' variables. The *adjusted* VIF is calculated as `VIF^(1/(2*<nlevels>)` (Fox &
+#' Monette 1992), which is identical to the square root of the VIF for numeric
+#' predictors, or for categorical variables with two levels.
+#'
 #' @section Multicollinearity:
 #' Multicollinearity should not be confused with a raw strong correlation
 #' between predictors. What matters is the association between one or more
@@ -61,7 +67,7 @@
 #' correlation of that predictor with other predictors. A value between 5 and
 #' 10 indicates a moderate correlation, while VIF values larger than 10 are a
 #' sign for high, not tolerable correlation of model predictors (_James et al.
-#' 2013_). The *Increased SE* column in the output indicates how much larger
+#' 2013_). The *adjusted VIF* column in the output indicates how much larger
 #' the standard error is due to the association with other predictors
 #' conditional on the remaining variables in the model. Note that these
 #' thresholds, although commonly used, are also criticized for being too high.
@@ -95,6 +101,9 @@
 #'
 #' @references
 #'
+#' - Fox, J., & Monette, G. (1992). Generalized Collinearity Diagnostics.
+#'   Journal of the American Statistical Association, 87(417), 178–183.
+#'
 #' - Francoeur, R. B. (2013). Could Sequential Residual Centering Resolve
 #'   Low Sensitivity in Moderated Regression? Simulations and Cancer Symptom
 #'   Clusters. Open Journal of Statistics, 03(06), 24-44.
@@ -114,8 +123,8 @@
 #' - McElreath, R. (2020). Statistical rethinking: A Bayesian course with
 #'   examples in R and Stan. 2nd edition. Chapman and Hall/CRC.
 #'
-#' - Vanhove, J. (2019). Collinearity isn't a disease that needs curing.
-#'   [webpage](https://janhove.github.io/posts/2019-09-11-collinearity/)
+#' - Vanhove, J. (2021) Collinearity Isn’t a Disease That Needs Curing.
+#'   Meta-Psychology, 5. \doi{10.15626/MP.2021.2548}
 #'
 #' - Zuur AF, Ieno EN, Elphick CS. A protocol for data exploration to avoid
 #'   common statistical problems: Data exploration. Methods in Ecology and
@@ -201,7 +210,7 @@ plot.check_collinearity <- function(x, ...) {
   x <- datawizard::data_rename(
     x,
     select = "SE_factor",
-    replacement = "Increased SE",
+    replacement = "adj. VIF",
     verbose = FALSE
   )
 
@@ -304,56 +313,81 @@ check_collinearity.betamfx <- check_collinearity.logitor
 
 #' @rdname check_collinearity
 #' @export
-check_collinearity.glmmTMB <- function(x,
-                                       component = c("all", "conditional", "count", "zi", "zero_inflated"),
-                                       ci = 0.95,
-                                       verbose = TRUE,
-                                       ...) {
-  component <- match.arg(component)
+check_collinearity.glmmTMB <- function(
+  x,
+  component = "all",
+  ci = 0.95,
+  verbose = TRUE,
+  ...
+) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
 
 #' @export
-check_collinearity.MixMod <- function(x,
-                                      component = c("all", "conditional", "count", "zi", "zero_inflated"),
-                                      ci = 0.95,
-                                      verbose = TRUE,
-                                      ...) {
-  component <- match.arg(component)
+check_collinearity.MixMod <- function(
+  x,
+  component = "all",
+  ci = 0.95,
+  verbose = TRUE,
+  ...
+) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
 
 #' @export
-check_collinearity.hurdle <- function(x,
-                                      component = c("all", "conditional", "count", "zi", "zero_inflated"),
-                                      ci = 0.95,
-                                      verbose = verbose,
-                                      ...) {
-  component <- match.arg(component)
+check_collinearity.hurdle <- function(
+  x,
+  component = "all",
+  ci = 0.95,
+  verbose = verbose,
+  ...
+) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
 
 #' @export
-check_collinearity.zeroinfl <- function(x,
-                                        component = c("all", "conditional", "count", "zi", "zero_inflated"),
-                                        ci = 0.95,
-                                        verbose = verbose,
-                                        ...) {
-  component <- match.arg(component)
+check_collinearity.zeroinfl <- function(
+  x,
+  component = "all",
+  ci = 0.95,
+  verbose = verbose,
+  ...
+) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
 
 #' @export
-check_collinearity.zerocount <- function(x,
-                                         component = c("all", "conditional", "count", "zi", "zero_inflated"),
-                                         ci = 0.95,
-                                         verbose = verbose,
-                                         ...) {
-  component <- match.arg(component)
+check_collinearity.zerocount <- function(
+  x,
+  component = "all",
+  ci = 0.95,
+  verbose = verbose,
+  ...
+) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "count", "zi", "zero_inflated")
+  )
   .check_collinearity_zi_model(x, component, ci = ci, verbose = verbose)
 }
 
@@ -361,11 +395,17 @@ check_collinearity.zerocount <- function(x,
 # utilities ---------------------------------
 
 .check_collinearity_zi_model <- function(x, component, ci = 0.95, verbose = TRUE) {
-  if (component == "count") component <- "conditional"
-  if (component == "zi") component <- "zero_inflated"
+  if (component == "count") {
+    component <- "conditional"
+  }
+  if (component == "zi") {
+    component <- "zero_inflated"
+  }
 
   mi <- insight::model_info(x, verbose = FALSE)
-  if (!mi$is_zero_inflated) component <- "conditional"
+  if (!mi$is_zero_inflated) {
+    component <- "conditional"
+  }
 
   if (component == "all") {
     cond <- .check_collinearity(x, "conditional", ci = ci, verbose = verbose)
@@ -415,7 +455,10 @@ check_collinearity.zerocount <- function(x,
     if (isTRUE(verbose)) {
       insight::format_alert(
         paste(
-          sprintf("Could not extract the variance-covariance matrix for the %s component of the model.", component),
+          sprintf(
+            "Could not extract the variance-covariance matrix for the %s component of the model.",
+            component
+          ),
           "Please try to run `vcov(model)`, which may help identifying the problem."
         )
       )
@@ -429,13 +472,15 @@ check_collinearity.zerocount <- function(x,
   if (is.null(term_assign) || all(is.na(term_assign))) {
     if (verbose) {
       insight::format_alert(
-        sprintf("Could not extract model terms for the %s component of the model.", component)
+        sprintf(
+          "Could not extract model terms for the %s component of the model.",
+          component
+        )
       )
     }
     return(NULL)
   }
 
-
   # we have rank-deficiency here. remove NA columns from assignment
   if (isTRUE(attributes(v)$rank_deficient) && !is.null(attributes(v)$na_columns_index)) {
     term_assign <- term_assign[-attributes(v)$na_columns_index]
@@ -458,9 +503,11 @@ check_collinearity.zerocount <- function(x,
 
   # hurdle or zeroinfl model can have no zero-inflation formula, in which case
   # we have the same formula as for conditional formula part
-  if (inherits(x, c("hurdle", "zeroinfl", "zerocount")) &&
-    component == "zero_inflated" &&
-    is.null(f[["zero_inflated"]])) {
+  if (
+    inherits(x, c("hurdle", "zeroinfl", "zerocount")) &&
+      component == "zero_inflated" &&
+      is.null(f[["zero_inflated"]])
+  ) {
     f$zero_inflated <- f$conditional
   }
 
@@ -479,7 +526,10 @@ check_collinearity.zerocount <- function(x,
   if (n.terms < 2) {
     if (isTRUE(verbose)) {
       insight::format_alert(
-        sprintf("Not enough model terms in the %s part of the model to check for multicollinearity.", component)
+        sprintf(
+          "Not enough model terms in the %s part of the model to check for multicollinearity.",
+          component
+        )
       )
     }
     return(NULL)
@@ -521,12 +571,54 @@ check_collinearity.zerocount <- function(x,
     )
   }
 
+  # check if CIs are requested
+  conf_ints <- .vif_ci(x, result, ci)
+
+  out <- insight::text_remove_backticks(
+    data.frame(
+      Term = model_terms,
+      VIF = result,
+      VIF_CI_low = 1 / (1 - conf_ints$CI_low),
+      VIF_CI_high = 1 / (1 - conf_ints$CI_high),
+      SE_factor = .adjusted_vif(x, result, model_terms),
+      Tolerance = 1 / result,
+      Tolerance_CI_low = 1 - conf_ints$CI_high,
+      Tolerance_CI_high = 1 - conf_ints$CI_low,
+      stringsAsFactors = FALSE
+    ),
+    column = "Term"
+  )
+  attr(out, "ci") <- ci
+
+  attr(out, "data") <- insight::text_remove_backticks(
+    data.frame(
+      Term = model_terms,
+      VIF = result,
+      SE_factor = .adjusted_vif(x, result, model_terms),
+      stringsAsFactors = FALSE
+    ),
+    column = "Term"
+  )
+
+  attr(out, "CI") <- data.frame(
+    VIF_CI_low = 1 / (1 - conf_ints$CI_low),
+    VIF_CI_high = 1 / (1 - conf_ints$CI_high),
+    Tolerance_CI_low = 1 - conf_ints$CI_high,
+    Tolerance_CI_high = 1 - conf_ints$CI_low,
+    stringsAsFactors = FALSE
+  )
+
+  class(out) <- c("check_collinearity", "see_check_collinearity", "data.frame")
+  out
+}
+
+
+.vif_ci <- function(x, result, ci) {
   # CIs, see Appendix B 10.1177/0013164418817803
   r <- 1 - (1 / result)
   n <- insight::n_obs(x)
   p <- insight::n_parameters(x)
 
-  # check if CIs are requested
   if (!is.null(ci) && !is.na(ci) && is.numeric(ci)) {
     ci_lvl <- (1 + ci) / 2
 
@@ -540,43 +632,32 @@ check_collinearity.zerocount <- function(x,
   } else {
     ci_lo <- ci_up <- NA
   }
+  list(CI_low = ci_lo, CI_high = ci_up)
+}
 
-  out <- insight::text_remove_backticks(
-    data.frame(
-      Term = model_terms,
-      VIF = result,
-      VIF_CI_low = 1 / (1 - ci_lo),
-      VIF_CI_high = 1 / (1 - ci_up),
-      SE_factor = sqrt(result),
-      Tolerance = 1 / result,
-      Tolerance_CI_low = 1 - ci_up,
-      Tolerance_CI_high = 1 - ci_lo,
-      stringsAsFactors = FALSE
-    ),
-    column = "Term"
+
+.adjusted_vif <- function(x, result, model_terms) {
+  tryCatch(
+    {
+      # get data from model frame, so we know which variables are factors
+      d <- insight::get_data(x, source = "mf", verbose = FALSE)
+      # degrees of freedom per variable - init to 1
+      dof <- rep_len(1, length(model_terms))
+      # find factors, which were converted inside formula. we need to convert
+      # these into real factors now, to determine their number of levels
+      factors <- attributes(d)$factors
+      d[factors] <- lapply(d[factors], as.factor)
+      # add factors from data frame
+      factors <- unique(c(factors, colnames(d)[vapply(d, is.factor, logical(1))]))
+      # find position of factors in model terms
+      pos <- match(factors, insight::clean_names(model_terms))
+      # copy df for factors
+      dof[pos] <- vapply(d[factors], nlevels, numeric(1)) - 1
+      # finally, calculate adjusted vif
+      result^(1 / (2 * dof))
+    },
+    error = function(e) sqrt(result)
   )
-  attr(out, "ci") <- ci
-
-  attr(out, "data") <- insight::text_remove_backticks(
-    data.frame(
-      Term = model_terms,
-      VIF = result,
-      SE_factor = sqrt(result),
-      stringsAsFactors = FALSE
-    ),
-    column = "Term"
-  )
-
-  attr(out, "CI") <- data.frame(
-    VIF_CI_low = 1 / (1 - ci_lo),
-    VIF_CI_high = 1 / (1 - ci_up),
-    Tolerance_CI_low = 1 - ci_up,
-    Tolerance_CI_high = 1 - ci_lo,
-    stringsAsFactors = FALSE
-  )
-
-  class(out) <- c("check_collinearity", "see_check_collinearity", "data.frame")
-  out
 }
 
 
@@ -584,17 +665,20 @@ check_collinearity.zerocount <- function(x,
   tryCatch(
     {
       if (inherits(x, c("hurdle", "zeroinfl", "zerocount"))) {
-        term_assign <- switch(component,
+        term_assign <- switch(
+          component,
           conditional = attr(insight::get_modelmatrix(x, model = "count"), "assign"),
           zero_inflated = attr(insight::get_modelmatrix(x, model = "zero"), "assign")
         )
       } else if (inherits(x, "glmmTMB")) {
-        term_assign <- switch(component,
+        term_assign <- switch(
+          component,
           conditional = attr(insight::get_modelmatrix(x), "assign"),
           zero_inflated = .zi_term_assignment(x, component, verbose = verbose)
         )
       } else if (inherits(x, "MixMod")) {
-        term_assign <- switch(component,
+        term_assign <- switch(
+          component,
           conditional = attr(insight::get_modelmatrix(x, type = "fixed"), "assign"),
           zero_inflated = attr(insight::get_modelmatrix(x, type = "zi_fixed"), "assign")
         )
@@ -637,7 +721,10 @@ check_collinearity.zerocount <- function(x,
   }))
 
   if (insight::is_gam_model(x)) {
-    model_params <- as.vector(unlist(insight::find_parameters(x)[c(component, "smooth_terms")]))
+    model_params <- as.vector(unlist(insight::find_parameters(x)[c(
+      component,
+      "smooth_terms"
+    )]))
   } else {
     model_params <- insight::find_parameters(x)[[component]]
   }
