@@ -27,10 +27,9 @@
 #' check_heteroscedasticity(m)
 #'
 #' # plot results
-#' if (require("see")) {
-#'   x <- check_heteroscedasticity(m)
-#'   plot(x)
-#' }
+#' @examplesIf insight::check_if_installed("see", minimum_version = "0.9.1", quietly = TRUE)
+#' x <- check_heteroscedasticity(m)
+#' plot(x)
 #' @export
 check_heteroscedasticity <- function(x, ...) {
   UseMethod("check_heteroscedasticity")
@@ -46,7 +45,6 @@ check_heteroskedasticity <- check_heteroscedasticity
 
 #' @export
 check_heteroscedasticity.default <- function(x, ...) {
-  # check for valid input
   .is_model_valid(x)
 
   # only for linear models
@@ -54,7 +52,10 @@ check_heteroscedasticity.default <- function(x, ...) {
   if (!info$is_linear) {
     msg <- "This Breusch-Pagan Test currently only works Gaussian models."
     if (info$is_count) {
-      paste0(msg, " You may check your model for overdispersion or zero-inflation instead (see 'check_overdispersion()' and 'check_zeroinflation()').")
+      paste0(
+        msg,
+        " You may check your model for overdispersion or zero-inflation instead (see 'check_overdispersion()' and 'check_zeroinflation()')."
+      )
     }
     insight::format_alert(msg)
     return(NULL)
@@ -66,7 +67,7 @@ check_heteroscedasticity.default <- function(x, ...) {
   .U <- (r^2) / S.sq
   mod <- stats::lm(.U ~ stats::fitted(x))
 
-  SS <- stats::anova(mod)$"Sum Sq"
+  SS <- stats::anova(mod)$`Sum Sq`
   RegSS <- sum(SS) - SS[length(SS)]
   Chisq <- RegSS / 2
 
@@ -74,13 +75,16 @@ check_heteroscedasticity.default <- function(x, ...) {
 
   attr(p.val, "data") <- x
   attr(p.val, "object_name") <- insight::safe_deparse_symbol(substitute(x))
-  class(p.val) <- unique(c("check_heteroscedasticity", "see_check_heteroscedasticity", class(p.val)))
+  class(p.val) <- unique(c(
+    "check_heteroscedasticity",
+    "see_check_heteroscedasticity",
+    class(p.val)
+  ))
 
   p.val
 }
 
 
-
 # methods -----------------------
 
 #' @export
@@ -113,7 +117,6 @@ plot.check_heteroscedasticity <- function(x, ...) {
 }
 
 
-
 # utilities -----------------------
 
 .sigma <- function(x) {
