@@ -2,7 +2,7 @@
 #'
 #' For univariate distributions (one-dimensional vectors), this functions
 #' performs a Ameijeiras-Alonso et al. (2018) excess mass test. For multivariate
-#' distributions (dataframes), it uses mixture modelling. However, it seems that
+#' distributions (data frames), it uses mixture modelling. However, it seems that
 #' it always returns a significant result (suggesting that the distribution is
 #' multimodal). A better method might be needed here.
 #'
@@ -10,33 +10,29 @@
 #' @param x A numeric vector or a data frame.
 #' @param ... Arguments passed to or from other methods.
 #'
-#' @examples
-#' \dontrun{
-#' if (require("multimode")) {
-#'   # Univariate
-#'   x <- rnorm(1000)
-#'   check_multimodal(x)
-#' }
+#' @examplesIf require("multimode") && require("mclust")
+#' \donttest{
+#' # Univariate
+#' x <- rnorm(1000)
+#' check_multimodal(x)
 #'
-#' if (require("multimode") && require("mclust")) {
-#'   x <- c(rnorm(1000), rnorm(1000, 2))
-#'   check_multimodal(x)
+#' x <- c(rnorm(1000), rnorm(1000, 2))
+#' check_multimodal(x)
 #'
-#'   # Multivariate
-#'   m <- data.frame(
-#'     x = rnorm(200),
-#'     y = rbeta(200, 2, 1)
-#'   )
-#'   plot(m$x, m$y)
-#'   check_multimodal(m)
+#' # Multivariate
+#' m <- data.frame(
+#'   x = rnorm(200),
+#'   y = rbeta(200, 2, 1)
+#' )
+#' plot(m$x, m$y)
+#' check_multimodal(m)
 #'
-#'   m <- data.frame(
-#'     x = c(rnorm(100), rnorm(100, 4)),
-#'     y = c(rbeta(100, 2, 1), rbeta(100, 1, 4))
-#'   )
-#'   plot(m$x, m$y)
-#'   check_multimodal(m)
-#' }
+#' m <- data.frame(
+#'   x = c(rnorm(100), rnorm(100, 4)),
+#'   y = c(rbeta(100, 2, 1), rbeta(100, 1, 4))
+#' )
+#' plot(m$x, m$y)
+#' check_multimodal(m)
 #' }
 #' @references
 #' - Ameijeiras-Alonso, J., Crujeiras, R. M., and Rodríguez-Casal, A. (2019).
@@ -62,31 +58,34 @@ check_multimodal.data.frame <- function(x, ...) {
   rez$p <- 1 - stats::pchisq(rez$Chisq, df = rez$df)
 
   # Text
-  text <- "The parametric mixture modelling test suggests that "
+  msg <- "The parametric mixture modelling test suggests that "
   if (rez$p < 0.05) {
-    text <- paste0(
-      text,
+    msg <- paste0(
+      msg,
       "the multivariate distribution is significantly multimodal (Chi2(",
       insight::format_value(rez$df, protect_integers = TRUE),
       ") = ",
       insight::format_value(rez$Chisq),
-      ", ", insight::format_p(rez$p), ").\n"
+      ", ",
+      insight::format_p(rez$p),
+      ").\n"
     )
     color <- "green"
   } else {
-    text <- paste0(
-      text,
+    msg <- paste0(
+      msg,
       "the hypothesis of a multimodal multivariate distribution cannot be rejected (Chi2(",
       insight::format_value(rez$df, protect_integers = TRUE),
       ") = ",
       insight::format_value(rez$Chisq),
-      ", ", insight::format_p(rez$p), ").\n"
+      ", ",
+      insight::format_p(rez$p),
+      ").\n"
     )
     color <- "yellow"
   }
 
-
-  attr(rez, "text") <- insight::format_message(text)
+  attr(rez, "text") <- insight::format_message(msg)
   attr(rez, "color") <- color
   attr(rez, "title") <- "Is the data multimodal?"
   class(rez) <- c("easystats_check", class(rez))
@@ -95,7 +94,6 @@ check_multimodal.data.frame <- function(x, ...) {
 }
 
 
-
 #' @export
 check_multimodal.numeric <- function(x, ...) {
   insight::check_if_installed("multimode")
@@ -103,27 +101,31 @@ check_multimodal.numeric <- function(x, ...) {
   rez <- multimode::modetest(x, mod0 = 1, method = "ACR")
   rez <- list(p = rez$p.value, excess_mass = rez$statistic)
 
-  text <- "The Ameijeiras-Alonso et al. (2018) excess mass test suggests that "
+  msg <- "The Ameijeiras-Alonso et al. (2018) excess mass test suggests that "
 
   if (rez$p < 0.05) {
-    text <- paste0(
-      text,
+    msg <- paste0(
+      msg,
       "the distribution is significantly multimodal (excess mass = ",
       insight::format_value(rez$excess_mass),
-      ", ", insight::format_p(rez$p), ").\n"
+      ", ",
+      insight::format_p(rez$p),
+      ").\n"
     )
     color <- "green"
   } else {
-    text <- paste0(
-      text,
+    msg <- paste0(
+      msg,
       "the hypothesis of a multimodal distribution cannot be rejected (excess mass = ",
       insight::format_value(rez$excess_mass),
-      ", ", insight::format_p(rez$p), ").\n"
+      ", ",
+      insight::format_p(rez$p),
+      ").\n"
     )
     color <- "yellow"
   }
 
-  attr(rez, "text") <- insight::format_message(text)
+  attr(rez, "text") <- insight::format_message(msg)
   attr(rez, "color") <- color
   attr(rez, "title") <- "Is the variable multimodal?"
   class(rez) <- c("easystats_check", class(rez))
