@@ -46,7 +46,7 @@
 #' @details An example how posterior predictive checks can also be used for model
 #'   comparison is Figure 6 from _Gabry et al. 2019, Figure 6_.
 #'
-#'   \if{html}{\cr \figure{pp_check.png}{options: width="90\%" alt="Posterior Predictive Check"} \cr}
+#'   \if{html}{\cr \figure{pp_check.png}{options: style="width: 25\%;" alt="Posterior Predictive Check"} \cr}
 #'   The model shown in the right panel (b) can simulate new data that are more
 #'   similar to the observed outcome than the model in the left panel (a). Thus,
 #'   model (b) is likely to be preferred over model (a).
@@ -98,14 +98,16 @@ check_predictions <- function(object, ...) {
 
 #' @rdname check_predictions
 #' @export
-check_predictions.default <- function(object,
-                                      iterations = 50,
-                                      check_range = FALSE,
-                                      re_formula = NULL,
-                                      bandwidth = "nrd",
-                                      type = "density",
-                                      verbose = TRUE,
-                                      ...) {
+check_predictions.default <- function(
+  object,
+  iterations = 50,
+  check_range = FALSE,
+  re_formula = NULL,
+  bandwidth = "nrd",
+  type = "density",
+  verbose = TRUE,
+  ...
+) {
   .is_model_valid(object)
   # check_predictions() can't handle exotic formula notation
   if (verbose) {
@@ -120,13 +122,20 @@ check_predictions.default <- function(object,
   minfo <- insight::model_info(object, verbose = FALSE)
 
   # try to find sensible default for "type" argument
-  suggest_dots <- (minfo$is_bernoulli || minfo$is_count || minfo$is_ordinal || minfo$is_categorical || minfo$is_multinomial) # nolint
+  suggest_dots <- (minfo$is_bernoulli ||
+    minfo$is_count ||
+    minfo$is_ordinal ||
+    minfo$is_categorical ||
+    minfo$is_multinomial) # nolint
   if (missing(type) && suggest_dots) {
     type <- "discrete_interval"
   }
 
   # args
-  type <- match.arg(type, choices = c("density", "discrete_dots", "discrete_interval", "discrete_both"))
+  type <- insight::validate_argument(
+    type,
+    c("density", "discrete_dots", "discrete_interval", "discrete_both")
+  )
 
   pp_check.lm(
     object,
@@ -143,31 +152,37 @@ check_predictions.default <- function(object,
 
 
 #' @export
-check_predictions.stanreg <- function(object,
-                                      iterations = 50,
-                                      check_range = FALSE,
-                                      re_formula = NULL,
-                                      bandwidth = "nrd",
-                                      type = "density",
-                                      verbose = TRUE,
-                                      ...) {
+check_predictions.stanreg <- function(
+  object,
+  iterations = 50,
+  check_range = FALSE,
+  re_formula = NULL,
+  bandwidth = "nrd",
+  type = "density",
+  verbose = TRUE,
+  ...
+) {
   # retrieve model information
   minfo <- insight::model_info(object, verbose = FALSE)
 
   # try to find sensible default for "type" argument
-  suggest_dots <- (minfo$is_bernoulli || minfo$is_count || minfo$is_ordinal || minfo$is_categorical || minfo$is_multinomial) # nolint
+  suggest_dots <- (minfo$is_bernoulli ||
+    minfo$is_count ||
+    minfo$is_ordinal ||
+    minfo$is_categorical ||
+    minfo$is_multinomial) # nolint
   if (missing(type) && suggest_dots) {
     type <- "discrete_interval"
   }
 
   # args
-  type <- match.arg(type, choices = c("density", "discrete_dots", "discrete_interval", "discrete_both"))
+  type <- insight::validate_argument(
+    type,
+    c("density", "discrete_dots", "discrete_interval", "discrete_both")
+  )
 
   # convert to type-argument for pp_check
-  pp_type <- switch(type,
-    density = "dens",
-    "bars"
-  )
+  pp_type <- switch(type, density = "dens", "bars")
 
   insight::check_if_installed(
     "bayesplot",
@@ -178,9 +193,13 @@ check_predictions.stanreg <- function(object,
   resp_string <- insight::find_terms(object)$response
 
   if (inherits(object, "brmsfit")) {
-    out <- as.data.frame(bayesplot::pp_check(object, type = pp_type, ndraws = iterations, ...)$data)
+    out <- as.data.frame(
+      bayesplot::pp_check(object, type = pp_type, ndraws = iterations, ...)$data
+    )
   } else {
-    out <- as.data.frame(bayesplot::pp_check(object, type = pp_type, nreps = iterations, ...)$data)
+    out <- as.data.frame(
+      bayesplot::pp_check(object, plotfun = pp_type, nreps = iterations, ...)$data
+    )
   }
 
   # bring data into shape, like we have for other models with `check_predictions()`
@@ -207,6 +226,11 @@ check_predictions.stanreg <- function(object,
     )
   }
 
+  # make x cateogorical for bernoulli/categorical/multinomial models
+  if (minfo$is_bernoulli || minfo$is_categorical || minfo$is_multinomial) {
+    out$x <- as.factor(out$x)
+  }
+
   attr(out, "is_stan") <- TRUE
   attr(out, "check_range") <- check_range
   attr(out, "response_name") <- resp_string
@@ -222,13 +246,15 @@ check_predictions.brmsfit <- check_predictions.stanreg
 
 
 #' @export
-check_predictions.BFBayesFactor <- function(object,
-                                            iterations = 50,
-                                            check_range = FALSE,
-                                            re_formula = NULL,
-                                            bandwidth = "nrd",
-                                            verbose = TRUE,
-                                            ...) {
+check_predictions.BFBayesFactor <- function(
+  object,
+  iterations = 50,
+  check_range = FALSE,
+  re_formula = NULL,
+  bandwidth = "nrd",
+  verbose = TRUE,
+  ...
+) {
   everything_we_need <- .get_bfbf_predictions(object, iterations = iterations)
 
   y <- everything_we_need[["y"]]
@@ -259,24 +285,43 @@ pp_check.BFBayesFactor <- check_predictions.BFBayesFactor
 
 #' @export
 check_predictions.lme <- function(object, ...) {
-  insight::format_error("`check_predictions()` does currently not work for models of class `lme`.")
+  insight::format_error(
+    "`check_predictions()` does currently not work for models of class `lme`."
+  )
 }
 
 
 # pp-check functions -------------------------------------
 
-pp_check.lm <- function(object,
-                        iterations = 50,
-                        check_range = FALSE,
-                        re_formula = NULL,
-                        bandwidth = "nrd",
-                        type = "density",
-                        verbose = TRUE,
-                        model_info = NULL,
-                        ...) {
+pp_check.lm <- function(
+  object,
+  iterations = 50,
+  check_range = FALSE,
+  re_formula = NULL,
+  bandwidth = "nrd",
+  type = "density",
+  verbose = TRUE,
+  model_info = NULL,
+  ...
+) {
+  # we need the formula and the response values to check for matrix responses
+  # or proportions in binomial models
+  model_response <- insight::find_response(object, combine = TRUE)
+  response_values <- insight::get_response(object)
+
   # if we have a matrix-response, continue here...
-  if (grepl("^cbind\\((.*)\\)", insight::find_response(object, combine = TRUE))) {
-    return(pp_check.glm(object, iterations, check_range, re_formula, bandwidth, type, verbose, model_info, ...))
+  if (grepl("^cbind\\((.*)\\)", model_response) || is.matrix(response_values)) {
+    return(pp_check.glm(
+      object,
+      iterations,
+      check_range,
+      re_formula,
+      bandwidth,
+      type,
+      verbose,
+      model_info,
+      ...
+    ))
   }
 
   # else, proceed as usual
@@ -294,12 +339,26 @@ pp_check.lm <- function(object,
 
   # glmmTMB returns column matrix for bernoulli
   if (inherits(object, "glmmTMB") && minfo$is_binomial && !is.null(out)) {
+    # check if we have a response defined as proportions. in that case, we
+    # have to handle the results from `simulate()` differently. We have a
+    # proportion response if the formula contains a `/` in the response,
+    # or if the response is a non-integer numeric vector between 0 and 1.
+    proportion_response <- grepl("/", model_response, fixed = TRUE) ||
+      (!is.null(response_values) && !all(.is_integer(response_values)))
+
     out <- as.data.frame(lapply(out, function(i) {
       if (is.matrix(i)) {
-        i[, 1]
-      } else {
-        i
+        # do we have a response defined as proportions?
+        if (proportion_response) {
+          # if so, calculate the proportions
+          i <- i[, 1] / rowSums(i, na.rm = TRUE)
+        } else {
+          # if not, we just take the first column
+          i <- i[, 1]
+        }
       }
+      # and return as a vector
+      as.vector(i)
     }))
   }
 
@@ -316,14 +375,19 @@ pp_check.lm <- function(object,
   pattern <- "^(scale|exp|expm1|log|log1p|log10|log2|sqrt)"
 
   # check for transformed response, and backtransform simulations
-  if (!is.null(resp_string) && length(resp_string) == 1 && grepl(paste0(pattern, "\\("), resp_string)) {
+  if (
+    !is.null(resp_string) &&
+      length(resp_string) == 1 &&
+      grepl(paste0(pattern, "\\("), resp_string)
+  ) {
     out <- .backtransform_sims(out, resp_string)
   }
 
   # sanity check - do we have a ratio or similar?
   if (is.data.frame(response)) {
     # get response data, evaluate formula
-    response <- eval(str2lang(insight::find_response(object)),
+    response <- eval(
+      str2lang(insight::find_response(object)),
       envir = insight::get_response(object)
     )
   }
@@ -340,18 +404,35 @@ pp_check.lm <- function(object,
 }
 
 
-pp_check.glm <- function(object,
-                         iterations = 50,
-                         check_range = FALSE,
-                         re_formula = NULL,
-                         bandwidth = "nrd",
-                         type = "density",
-                         verbose = TRUE,
-                         model_info = NULL,
-                         ...) {
+pp_check.glm <- function(
+  object,
+  iterations = 50,
+  check_range = FALSE,
+  re_formula = NULL,
+  bandwidth = "nrd",
+  type = "density",
+  verbose = TRUE,
+  model_info = NULL,
+  ...
+) {
+  # we need the formula and the response values to check for matrix responses
+  # or proportions in binomial models
+  model_response <- insight::find_response(object, combine = TRUE)
+  response_values <- insight::get_response(object)
+
   # if we have no matrix-response, continue here...
-  if (!grepl("^cbind\\((.*)\\)", insight::find_response(object, combine = TRUE))) {
-    return(pp_check.lm(object, iterations, check_range, re_formula, bandwidth, type, verbose, model_info, ...))
+  if (!grepl("^cbind\\((.*)\\)", model_response) && !is.matrix(response_values)) {
+    return(pp_check.lm(
+      object,
+      iterations,
+      check_range,
+      re_formula,
+      bandwidth,
+      type,
+      verbose,
+      model_info,
+      ...
+    ))
   }
 
   # else, process matrix response. for matrix response models, we compute
@@ -360,8 +441,17 @@ pp_check.glm <- function(object,
 
   out <- tryCatch(
     {
-      matrix_sim <- stats::simulate(object, nsim = iterations, re.form = re_formula, ...)
-      as.data.frame(sapply(matrix_sim, function(i) i[, 1] / rowSums(i, na.rm = TRUE), simplify = TRUE))
+      matrix_sim <- stats::simulate(
+        object,
+        nsim = iterations,
+        re.form = re_formula,
+        ...
+      )
+      as.data.frame(sapply(
+        matrix_sim,
+        function(i) i[, 1] / rowSums(i, na.rm = TRUE),
+        simplify = TRUE
+      ))
     },
     error = function(e) {
       NULL
@@ -369,7 +459,15 @@ pp_check.glm <- function(object,
   )
 
   # validation check, for mixed models, where re.form = NULL (default) might fail
-  out <- .check_re_formula(out, object, iterations, re_formula, verbose, ...)
+  out <- .check_re_formula(
+    out,
+    object,
+    iterations,
+    re_formula,
+    verbose,
+    as_proportion = TRUE,
+    ...
+  )
 
   if (is.null(out)) {
     insight::format_error(sprintf(
@@ -379,8 +477,12 @@ pp_check.glm <- function(object,
   }
 
   # get response data, and response term
-  response <- eval(str2lang(insight::find_response(object)),
-    envir = insight::get_response(object)
+  response <- .safe(
+    eval(
+      str2lang(insight::find_response(object)),
+      envir = insight::get_response(object)
+    ),
+    insight::get_response(object)
   )
   resp_string <- insight::find_terms(object)$response
 
@@ -398,27 +500,30 @@ pp_check.glm <- function(object,
   attr(out, "bandwidth") <- bandwidth
   attr(out, "model_info") <- minfo
   attr(out, "type") <- type
-  class(out) <- c("performance_pp_check", "see_performance_pp_check", class(out))
+  class(out) <- c(
+    "performance_pp_check",
+    "see_performance_pp_check",
+    class(out)
+  )
   out
 }
 
 
 # styler: off
-pp_check.glmmTMB   <-
-  pp_check.glm.nb  <-
-  pp_check.lme     <-
-  pp_check.merMod  <-
-  pp_check.MixMod  <-
-  pp_check.mle2    <-
-  pp_check.negbin  <-
-  pp_check.polr    <-
-  pp_check.rma     <-
-  pp_check.vlm     <-
-  pp_check.wbm     <-
-  pp_check.lm
+pp_check.glmmTMB <-
+  pp_check.glm.nb <-
+    pp_check.lme <-
+      pp_check.merMod <-
+        pp_check.MixMod <-
+          pp_check.mle2 <-
+            pp_check.negbin <-
+              pp_check.polr <-
+                pp_check.rma <-
+                  pp_check.vlm <-
+                    pp_check.wbm <-
+                      pp_check.lm
 # styler: on
 
-
 #' @rawNamespace
 #' S3method(bayesplot::pp_check, lm)
 #' S3method(bayesplot::pp_check, glm)
@@ -434,10 +539,8 @@ pp_check.glmmTMB   <-
 #' S3method(bayesplot::pp_check, wbm)
 #' S3method(bayesplot::pp_check, BFBayesFactor)
 
-
 # methods -----------------------
 
-
 #' @export
 print.performance_pp_check <- function(x, verbose = TRUE, ...) {
   original <- x$y
@@ -474,7 +577,8 @@ print.performance_pp_check <- function(x, verbose = TRUE, ...) {
               ifelse(length(missing_levs) == 1, " ", "s "),
               paste0("'", missing_levs, "'", collapse = ", "),
               " from original data is not included in the replicated data."
-            ), "Model may not capture the variation of the data."
+            ),
+            "Model may not capture the variation of the data."
           ),
           "red"
         )
@@ -505,10 +609,14 @@ plot.performance_pp_check <- function(x, ...) {
   } else if (grepl("log(", resp_string, fixed = TRUE)) {
     # exceptions: log(x+1) or log(1+x)
     # 1. try: log(x + number)
-    plus_minus <- .safe(eval(parse(text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\2", resp_string))))
+    plus_minus <- .safe(eval(parse(
+      text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\2", resp_string)
+    )))
     # 2. try: log(number + x)
     if (is.null(plus_minus)) {
-      plus_minus <- .safe(eval(parse(text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\1", resp_string))))
+      plus_minus <- .safe(eval(parse(
+        text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\1", resp_string)
+      )))
     }
     if (is.null(plus_minus) || !is.numeric(plus_minus)) {
       sims[] <- lapply(sims, exp)
@@ -533,7 +641,15 @@ plot.performance_pp_check <- function(x, ...) {
 }
 
 
-.check_re_formula <- function(out, object, iterations, re_formula, verbose, ...) {
+.check_re_formula <- function(
+  out,
+  object,
+  iterations,
+  re_formula,
+  verbose,
+  as_proportion = FALSE,
+  ...
+) {
   # validation check, for mixed models, where re.form = NULL (default) might fail
   if (is.null(out) && insight::is_mixed_model(object) && !isTRUE(is.na(re_formula))) {
     if (verbose) {
@@ -547,6 +663,14 @@ plot.performance_pp_check <- function(x, ...) {
       )
     }
     out <- .safe(stats::simulate(object, nsim = iterations, re.form = NA, ...))
+    # if we have a matrix response, convert to proportions
+    if (as_proportion) {
+      out <- as.data.frame(sapply(
+        out,
+        function(i) i[, 1] / rowSums(i, na.rm = TRUE),
+        simplify = TRUE
+      ))
+    }
   }
   out
 }
