@@ -24,7 +24,11 @@
     },
     error = function(e) {
       insight::format_error(
-        paste0("Could not compute gradients from a model object of class `", class(x)[1], "`."),
+        paste0(
+          "Could not compute gradients from a model object of class `",
+          class(x)[1],
+          "`."
+        ),
         "Please try a different test-function, or file an issue at {.url https://github.com/easystats/performance/issues}."
       )
     }
@@ -33,26 +37,31 @@
 
 
 .get_gradients.lmerMod <- function(x, ...) {
-  insight::get_residuals(x) * insight::get_weights(x, null_as_ones = TRUE) * insight::get_modelmatrix(x)
+  insight::get_residuals(x) *
+    insight::get_weights(x, null_as_ones = TRUE) *
+    insight::get_modelmatrix(x)
 }
 
 
 .get_gradients.glmerMod <- function(x, ...) {
-  w <- as.vector(insight::get_residuals(x, "working")) * insight::get_weights(x, "working")
+  w <- as.vector(insight::get_residuals(x, "working")) *
+    insight::get_weights(x, "working")
   w * insight::get_modelmatrix(x) / insight::get_auxiliary(x, type = "dispersion")
 }
 
 
 .get_gradients.glmmTMB <- function(x, ...) {
   if (insight::model_info(x)$is_linear) {
-    insight::get_residuals(x) * insight::get_weights(x, null_as_ones = TRUE) * insight::get_modelmatrix(x)
+    insight::get_residuals(x) *
+      insight::get_weights(x, null_as_ones = TRUE) *
+      insight::get_modelmatrix(x)
   } else {
-    w <- as.vector(insight::get_residuals(x)) * insight::get_weights(x, null_as_ones = TRUE)
+    w <- as.vector(insight::get_residuals(x)) *
+      insight::get_weights(x, null_as_ones = TRUE)
     w * insight::get_modelmatrix(x) / insight::get_auxiliary(x, type = "dispersion")
   }
 }
 
-
 # .get_gradients.lm <- .get_gradients.lmer
 #
 # .get_gradients.glm <- function(x, ...) {
