@@ -1,3 +1,13 @@
+# small wrapper around this commonly used try-catch
+.safe <- function(code, on_error = NULL) {
+  if (isTRUE(getOption("easystats_errors", FALSE)) && is.null(on_error)) {
+    code
+  } else {
+    tryCatch(code, error = function(e) on_error)
+  }
+}
+
+
 .get_BIC <- function(x, estimator = "ML") {
   # check ML estimator
   if (missing(estimator) && inherits(x, "lmerMod")) {
@@ -11,13 +21,17 @@
   } else if (inherits(x, "bayesx")) {
     out <- .adjust_ic_jacobian(x, stats::BIC(x)[["BIC"]])
   } else {
-    out <- tryCatch(
-      stats::BIC(insight::get_loglikelihood(x, check_response = TRUE, REML = REML, verbose = FALSE)),
-      error = function(e) NULL
+    out <- .safe(
+      stats::BIC(insight::get_loglikelihood(
+        x,
+        check_response = TRUE,
+        REML = REML,
+        verbose = FALSE
+      ))
     )
     # when `get_loglikelihood()` does not work, `stats::BIC` sometimes still works (e.g., `fixest`)
     if (is.null(out)) {
-      out <- tryCatch(stats::BIC(x), error = function(e) NULL)
+      out <- .safe(stats::BIC(x))
     }
   }
 
@@ -29,13 +43,10 @@
   if (!is.numeric(x)) {
     return(x)
   }
-
   # remove missings
   tmp <- x[!is.na(x)]
-
   # standardize
   tmp <- (tmp - mean(tmp)) / stats::sd(tmp)
-
   # and fill in values in original vector
   x[!is.na(x)] <- tmp
 
@@ -60,10 +71,10 @@
 
 .get_sigma <- function(model, verbose = TRUE) {
   s <- insight::get_sigma(model, ci = NULL, verbose = verbose)
-  if (!is.null(s)) {
-    as.numeric(s)
-  } else {
+  if (is.null(s)) {
     NULL
+  } else {
+    as.numeric(s)
   }
 }
 
