@@ -1,9 +1,11 @@
-#' Intraclass Correlation Coefficient (ICC)
+#' @title Intraclass Correlation Coefficient (ICC)
+#' @name icc
 #'
+#' @description
 #' This function calculates the intraclass-correlation coefficient (ICC) -
 #' sometimes also called *variance partition coefficient* (VPC) or
 #' *repeatability* - for mixed effects models. The ICC can be calculated for all
-#' models supported by `insight::get_variance()`. For models fitted with the
+#' models supported by [`insight::get_variance()`]. For models fitted with the
 #' **brms**-package, `icc()` might fail due to the large variety of
 #' models and families supported by the **brms**-package. In such cases, an
 #' alternative to the ICC is the `variance_decomposition()`, which is based
@@ -11,31 +13,36 @@
 #'
 #' @param model A (Bayesian) mixed effects model.
 #' @param re_formula Formula containing group-level effects to be considered in
-#'   the prediction. If `NULL` (default), include all group-level effects.
-#'   Else, for instance for nested models, name a specific group-level effect
-#'   to calculate the variance decomposition for this group-level. See 'Details'
-#'   and `?brms::posterior_predict`.
-#' @param ci Confidence resp. credible interval level. For `icc()` and `r2()`,
-#'   confidence intervals are based on bootstrapped samples from the ICC resp.
-#'   R2 value. See `iterations`.
-#' @param by_group Logical, if `TRUE`, `icc()` returns the variance
-#'   components for each random-effects level (if there are multiple levels).
-#'   See 'Details'.
+#' the prediction. If `NULL` (default), include all group-level effects.
+#' Else, for instance for nested models, name a specific group-level effect
+#' to calculate the variance decomposition for this group-level. See 'Details'
+#' and `?brms::posterior_predict`.
+#' @param ci Confidence resp. credible interval level. For `icc()`, `r2()`, and
+#' `rmse()`, confidence intervals are based on bootstrapped samples from the
+#' ICC, R2 or RMSE value. See `iterations`.
+#' @param by_group Logical, if `TRUE`, `icc()` returns the variance components
+#' for each random-effects level (if there are multiple levels). See 'Details'.
 #' @param iterations Number of bootstrap-replicates when computing confidence
-#'   intervals for the ICC or R2.
+#' intervals for the ICC, R2, RMSE etc.
 #' @param ci_method Character string, indicating the bootstrap-method. Should
-#'   be `NULL` (default), in which case `lme4::bootMer()` is used for
-#'   bootstrapped confidence intervals. However, if bootstrapped intervals cannot
-#'   be calculated this was, try `ci_method = "boot"`, which falls back to
-#'   `boot::boot()`. This may successfully return bootstrapped confidence intervals,
-#'   but bootstrapped samples may not be appropriate for the multilevel structure
-#'   of the model. There is also an option `ci_method = "analytical"`, which tries
-#'   to calculate analytical confidence assuming a chi-squared distribution.
-#'   However, these intervals are rather inaccurate and often too narrow. It is
-#'   recommended to calculate bootstrapped confidence intervals for mixed models.
+#' be `NULL` (default), in which case `lme4::bootMer()` is used for bootstrapped
+#' confidence intervals. However, if bootstrapped intervals cannot be calculated
+#' this way, try `ci_method = "boot"`, which falls back to `boot::boot()`. This
+#' may successfully return bootstrapped confidence intervals, but bootstrapped
+#' samples may not be appropriate for the multilevel structure of the model.
+#' There is also an option `ci_method = "analytical"`, which tries to calculate
+#' analytical confidence assuming a chi-squared distribution. However, these
+#' intervals are rather inaccurate and often too narrow. It is recommended to
+#' calculate bootstrapped confidence intervals for mixed models.
 #' @param verbose Toggle warnings and messages.
+#' @param null_model Optional, a null model to compute the random effect variances,
+#' which is passed to [`insight::get_variance()`]. Usually only required if
+#' calculation of r-squared or ICC fails when `null_model` is not specified. If
+#' calculating the null model takes longer and you already have fit the null
+#' model, you can pass it here, too, to speed up the process.
 #' @param ... Arguments passed down to `lme4::bootMer()` or `boot::boot()`
-#'   for bootstrapped ICC or R2.
+#' for bootstrapped ICC, R2, RMSE etc.; for `variance_decomposition()`,
+#' arguments are passed down to `brms::posterior_predict()`.
 #'
 #' @inheritParams r2_bayes
 #' @inheritParams insight::get_variance
@@ -58,6 +65,8 @@
 #'    applications and data analysis methods (2nd ed). Thousand Oaks: Sage
 #'    Publications.
 #'
+#' @inheritSection r2_nakagawa Supported models and model families
+#'
 #' @details
 #' ## Interpretation
 #' The ICC can be interpreted as "the proportion of the variance explained by
@@ -163,14 +172,19 @@
 #' )
 #' icc(model, by_group = TRUE)
 #' @export
-icc <- function(model,
-                by_group = FALSE,
-                tolerance = 1e-05,
-                ci = NULL,
-                iterations = 100,
-                ci_method = NULL,
-                verbose = TRUE,
-                ...) {
+icc <- function(
+  model,
+  by_group = FALSE,
+  tolerance = 1e-05,
+  ci = NULL,
+  iterations = 100,
+  ci_method = NULL,
+  null_model = NULL,
+  approximation = "lognormal",
+  model_component = NULL,
+  verbose = TRUE,
+  ...
+) {
   # special handling for smicd::semLme()
   if (inherits(model, "sem") && inherits(model, "lme")) {
     return(model$icc)
@@ -197,7 +211,14 @@ icc <- function(model,
   }
 
   # calculate random effect variances
-  vars <- .compute_random_vars(model, tolerance)
+  vars <- .compute_random_vars(
+    model,
+    tolerance = tolerance,
+    null_model = null_model,
+    approximation = approximation,
+    model_component = model_component,
+    verbose = verbose
+  )
 
   # return if ICC couldn't be computed
   if (is.null(vars) || all(is.na(vars))) {
@@ -214,13 +235,14 @@ icc <- function(model,
     }
 
     if (!is.null(ci) && !is.na(ci) && verbose) {
-      insight::format_alert("Confidence intervals are not yet supported for `by_group = TRUE`.")
+      insight::format_alert(
+        "Confidence intervals are not yet supported for `by_group = TRUE`."
+      )
     }
 
     # icc per group factor with reference to overall model
     icc_overall <- vars$var.intercept / (vars$var.random + vars$var.residual)
 
-
     out <- data.frame(
       Group = names(icc_overall),
       ICC = unname(icc_overall),
@@ -230,7 +252,12 @@ icc <- function(model,
     # iccs between groups
     # n_grps <- length(vars$var.intercept)
     # level_combinations <- utils::combn(1:n_grps, m = n_grps - 1, simplify = FALSE)
-    # icc_grp <- sapply(level_combinations, function(v) vars$var.intercept[v[1]] / (vars$var.intercept[v[1]] + vars$var.intercept[v[2]]))
+    # icc_grp <- sapply(
+    #   level_combinations,
+    #   function(v) {
+    #     vars$var.intercept[v[1]] / (vars$var.intercept[v[1]] + vars$var.intercept[v[2]])
+    #   }
+    # )
     #
     # out2 <- data.frame(
     #   Group1 = group_names[sapply(level_combinations, function(i) i[1])],
@@ -243,7 +270,8 @@ icc <- function(model,
   } else {
     # Calculate ICC values
     icc_adjusted <- vars$var.random / (vars$var.random + vars$var.residual)
-    icc_unadjusted <- vars$var.random / (vars$var.fixed + vars$var.random + vars$var.residual)
+    icc_unadjusted <- vars$var.random /
+      (vars$var.fixed + vars$var.random + vars$var.residual)
 
     out <- data.frame(
       ICC_adjusted = icc_adjusted,
@@ -256,11 +284,11 @@ icc <- function(model,
       # this is experimental!
       if (identical(ci_method, "analytical")) {
         result <- .safe(.analytical_icc_ci(model, ci))
-        if (!is.null(result)) {
+        if (is.null(result)) {
+          icc_ci_adjusted <- icc_ci_unadjusted <- NA
+        } else {
           icc_ci_adjusted <- result$ICC_adjusted
           icc_ci_unadjusted <- result$ICC_unadjusted
-        } else {
-          icc_ci_adjusted <- icc_ci_unadjusted <- NA
         }
       } else {
         result <- .bootstrap_icc(model, iterations, tolerance, ci_method, ...)
@@ -289,9 +317,18 @@ icc <- function(model,
         }
       }
       out_ci <- data.frame(
-        ICC_adjusted = c(CI_low = icc_ci_adjusted$CI_low, CI_high = icc_ci_adjusted$CI_high),
-        ICC_conditional = c(CI_low = icc_ci_unadjusted$CI_low, CI_high = icc_ci_unadjusted$CI_high),
-        ICC_unadjusted = c(CI_low = icc_ci_unadjusted$CI_low, CI_high = icc_ci_unadjusted$CI_high)
+        ICC_adjusted = c(
+          CI_low = icc_ci_adjusted$CI_low,
+          CI_high = icc_ci_adjusted$CI_high
+        ),
+        ICC_conditional = c(
+          CI_low = icc_ci_unadjusted$CI_low,
+          CI_high = icc_ci_unadjusted$CI_high
+        ),
+        ICC_unadjusted = c(
+          CI_low = icc_ci_unadjusted$CI_low,
+          CI_high = icc_ci_unadjusted$CI_high
+        )
       )
       out <- rbind(out, out_ci)
       attr(out, "ci") <- ci
@@ -303,16 +340,15 @@ icc <- function(model,
 }
 
 
-
-#' @param ... Arguments passed down to `brms::posterior_predict()`.
-#' @inheritParams icc
 #' @rdname icc
 #' @export
-variance_decomposition <- function(model,
-                                   re_formula = NULL,
-                                   robust = TRUE,
-                                   ci = 0.95,
-                                   ...) {
+variance_decomposition <- function(
+  model,
+  re_formula = NULL,
+  robust = TRUE,
+  ci = 0.95,
+  ...
+) {
   if (!inherits(model, "brmsfit")) {
     insight::format_error("Only models from package `brms` are supported.")
   }
@@ -348,7 +384,13 @@ variance_decomposition <- function(model,
 
   var_icc <- var_rand_intercept / var_total
   var_residual <- var_total - var_rand_intercept
-  ci_icc <- rev(1 - stats::quantile(var_rand_intercept / var_total, probs = c((1 - ci) / 2, (1 + ci) / 2)))
+  ci_icc <- rev(
+    1 -
+      stats::quantile(
+        var_rand_intercept / var_total,
+        probs = c((1 - ci) / 2, (1 + ci) / 2)
+      )
+  )
 
   result <- structure(
     class = "icc_decomposed",
@@ -377,7 +419,6 @@ variance_decomposition <- function(model,
 }
 
 
-
 # methods ------------------------------
 
 #' @export
@@ -404,14 +445,24 @@ print.icc <- function(x, digits = 3, ...) {
 
   # add CI
   if (length(x$ICC_adjusted) == 3) {
-    out[1] <- .add_r2_ci_to_print(out[1], x$ICC_adjusted[2], x$ICC_adjusted[3], digits = digits)
+    out[1] <- .add_r2_ci_to_print(
+      out[1],
+      x$ICC_adjusted[2],
+      x$ICC_adjusted[3],
+      digits = digits
+    )
   }
   if (length(x$ICC_unadjusted) == 3) {
-    out[2] <- .add_r2_ci_to_print(out[2], x$ICC_unadjusted[2], x$ICC_unadjusted[3], digits = digits)
+    out[2] <- .add_r2_ci_to_print(
+      out[2],
+      x$ICC_unadjusted[2],
+      x$ICC_unadjusted[3],
+      digits = digits
+    )
   }
 
   # separate lines for multiple R2
-  out <- paste0(out, collapse = "\n")
+  out <- paste(out, collapse = "\n")
 
   cat(out)
   cat("\n")
@@ -459,7 +510,10 @@ print.icc_decomposed <- function(x, digits = 2, ...) {
     ci.icc.hi
   ))
 
-  cat(insight::print_color("\n## Variances of Posterior Predicted Distribution\n", "blue"))
+  cat(insight::print_color(
+    "\n## Variances of Posterior Predicted Distribution\n",
+    "blue"
+  ))
 
   null.model <- sprintf("%.*f", digits, attr(x, "var_rand_intercept", exact = TRUE))
 
@@ -522,24 +576,30 @@ print.icc_decomposed <- function(x, digits = 2, ...) {
 }
 
 
-
 # helper -----------------
 
-.compute_random_vars <- function(model,
-                                 tolerance,
-                                 components = c("var.fixed", "var.random", "var.residual"),
-                                 name_fun = "icc()",
-                                 name_full = "ICC",
-                                 verbose = TRUE) {
+.compute_random_vars <- function(
+  model,
+  tolerance,
+  components = c("var.fixed", "var.random", "var.residual"),
+  name_fun = "icc()",
+  name_full = "ICC",
+  null_model = NULL,
+  model_component = NULL,
+  approximation = "lognormal",
+  verbose = TRUE
+) {
   vars <- tryCatch(
-    {
-      insight::get_variance(model,
-        name_fun = name_fun,
-        name_full = name_full,
-        tolerance = tolerance,
-        verbose = verbose
-      )
-    },
+    insight::get_variance(
+      model,
+      name_fun = name_fun,
+      name_full = name_full,
+      tolerance = tolerance,
+      null_model = null_model,
+      approximation = approximation,
+      model_component = model_component,
+      verbose = verbose
+    ),
     error = function(e) {
       if (inherits(e, c("simpleError", "error")) && verbose) {
         insight::print_color(e$message, "red")
@@ -570,7 +630,11 @@ print.icc_decomposed <- function(x, digits = 2, ...) {
 .boot_icc_fun <- function(data, indices, model, tolerance) {
   d <- data[indices, ] # allows boot to select sample
   fit <- suppressWarnings(suppressMessages(stats::update(model, data = d)))
-  vars <- .compute_random_vars(fit, tolerance, verbose = FALSE)
+  vars <- .compute_random_vars(
+    fit,
+    tolerance,
+    verbose = isTRUE(getOption("easystats_errors", FALSE))
+  )
   if (is.null(vars) || all(is.na(vars))) {
     return(c(NA, NA))
   }
@@ -583,7 +647,11 @@ print.icc_decomposed <- function(x, digits = 2, ...) {
 
 # bootstrapping using "lme4::bootMer"
 .boot_icc_fun_lme4 <- function(model) {
-  vars <- .compute_random_vars(model, tolerance = 1e-05, verbose = FALSE)
+  vars <- .compute_random_vars(
+    model,
+    tolerance = 1e-10,
+    verbose = isTRUE(getOption("easystats_errors", FALSE))
+  )
   if (is.null(vars) || all(is.na(vars))) {
     return(c(NA, NA))
   }
@@ -597,7 +665,7 @@ print.icc_decomposed <- function(x, digits = 2, ...) {
 # prepare arguments for "lme4::bootMer"
 .do_lme4_bootmer <- function(model, .boot_fun, iterations, dots) {
   insight::check_if_installed(c("lme4", "boot"))
-  args <- list(
+  my_args <- list(
     model,
     .boot_fun,
     nsim = iterations,
@@ -608,31 +676,33 @@ print.icc_decomposed <- function(x, digits = 2, ...) {
   )
   # add/overwrite dot-args
   if (!is.null(dots[["use.u"]])) {
-    args$use.u <- dots[["use.u"]]
+    my_args$use.u <- dots[["use.u"]]
   }
   if (!is.null(dots[["re.form"]])) {
-    args$re.form <- dots[["re.form"]]
+    my_args$re.form <- dots[["re.form"]]
   }
   if (!is.null(dots[["type"]])) {
-    args$type <- dots[["type"]]
-    if (args$type == "semiparametric") {
-      args$use.u <- TRUE
+    my_args$type <- dots[["type"]]
+    if (my_args$type == "semiparametric") {
+      my_args$use.u <- TRUE
     }
   }
   if (!is.null(dots[["parallel"]])) {
-    args$parallel <- dots[["parallel"]]
+    my_args$parallel <- dots[["parallel"]]
   }
   if (!is.null(dots[["ncpus"]])) {
-    args$ncpus <- dots[["ncpus"]]
+    my_args$ncpus <- dots[["ncpus"]]
   }
   # bootsrap
-  do.call(lme4::bootMer, args)
+  do.call(lme4::bootMer, args = my_args)
 }
 
 
 # main function for bootstrapping
 .bootstrap_icc <- function(model, iterations, tolerance, ci_method = NULL, ...) {
-  if (inherits(model, c("merMod", "lmerMod", "glmmTMB")) && !identical(ci_method, "boot")) {
+  if (
+    inherits(model, c("merMod", "lmerMod", "glmmTMB")) && !identical(ci_method, "boot")
+  ) {
     result <- .do_lme4_bootmer(
       model,
       .boot_icc_fun_lme4,
@@ -664,12 +734,10 @@ print.icc_decomposed <- function(x, digits = 2, ...) {
   }
 
   model_rank <- tryCatch(
-    {
-      if (!is.null(model$rank)) {
-        model$rank - df_int
-      } else {
-        insight::n_parameters(model) - df_int
-      }
+    if (is.null(model$rank)) {
+      insight::n_parameters(model) - df_int
+    } else {
+      model$rank - df_int
     },
     error = function(e) insight::n_parameters(model) - df_int
   )
