@@ -17,7 +17,9 @@
 model_performance.kmeans <- function(model, verbose = TRUE, ...) {
   out <- as.data.frame(model[c("totss", "tot.withinss", "betweenss", "iter")])
   colnames(out) <- c(
-    "Sum_Squares_Within", "Sum_Squares_Between", "Sum_Squares_Total",
+    "Sum_Squares_Total",
+    "Sum_Squares_Within",
+    "Sum_Squares_Between",
     "Iterations"
   )
 
