@@ -1,7 +1,7 @@
 #' Performance of Meta-Analysis Models
 #'
 #' Compute indices of model performance for meta-analysis model from the
-#' \pkg{metafor} package.
+#' **metafor** package.
 #'
 #' @param model A `rma` object as returned by `metafor::rma()`.
 #' @param metrics Can be `"all"` or a character vector of metrics to be
@@ -18,7 +18,7 @@
 #'
 #'   - **AIC** Akaike's Information Criterion, see `?stats::AIC`
 #'
-#'   - **BIC** {Bayesian Information Criterion, see `?stats::BIC`}
+#'   - **BIC** Bayesian Information Criterion, see `?stats::BIC`
 #'
 #'    - **I2**: For a random effects model, `I2` estimates (in
 #'    percent) how much of the total variability in the effect size estimates
@@ -36,7 +36,7 @@
 #'    or mixed effects model.
 #'
 #'    - **CochransQ (QE)**: Test for (residual) Heterogeneity. Without
-#'    moderators in the model, this is simply Cochran's Q-test.
+#'    moderators in the model, this is simply Cochran's *Q*-test.
 #'
 #'    - **Omnibus (QM)**: Omnibus test of parameters.
 #'
@@ -47,15 +47,26 @@
 #' See the documentation for `?metafor::fitstats`.
 #' }
 #'
-#' @examples
-#' if (require("metafor")) {
-#'   data(dat.bcg)
-#'   dat <- escalc(measure = "RR", ai = tpos, bi = tneg, ci = cpos, di = cneg, data = dat.bcg)
-#'   model <- rma(yi, vi, data = dat, method = "REML")
-#'   model_performance(model)
-#' }
+#' @examplesIf require("metafor") && require("metadat")
+#' data(dat.bcg, package = "metadat")
+#' dat <- metafor::escalc(
+#'   measure = "RR",
+#'   ai = tpos,
+#'   bi = tneg,
+#'   ci = cpos,
+#'   di = cneg,
+#'   data = dat.bcg
+#' )
+#' model <- metafor::rma(yi, vi, data = dat, method = "REML")
+#' model_performance(model)
 #' @export
-model_performance.rma <- function(model, metrics = "all", estimator = "ML", verbose = TRUE, ...) {
+model_performance.rma <- function(
+  model,
+  metrics = "all",
+  estimator = "ML",
+  verbose = TRUE,
+  ...
+) {
   if (all(metrics == "all")) {
     metrics <- c("AIC", "BIC", "I2", "H2", "TAU2", "COCHRANSQ", "OMNIBUS", "R2")
   } else if (all(metrics == "common")) {
@@ -89,14 +100,7 @@ model_performance.rma <- function(model, metrics = "all", estimator = "ML", verb
   if (any(c("QE", "COCHRANSQ") %in% toupper(metrics))) {
     out$CochransQ <- s$QE
     out$p_CochransQ <- s$QEp
-    out$df_error <- tryCatch(
-      {
-        stats::df.residual(model)
-      },
-      error = function(e) {
-        NULL
-      }
-    )
+    out$df_error <- .safe(stats::df.residual(model))
   }
 
   if (any(c("QM", "OMNIBUS") %in% toupper(metrics))) {
