@@ -1,6 +1,5 @@
 #' @export
 model_performance.default <- function(model, metrics = "all", verbose = TRUE, ...) {
-  # check for valid input
   .is_model_valid(model)
 
   if (any(tolower(metrics) == "log_loss")) {
@@ -8,7 +7,17 @@ model_performance.default <- function(model, metrics = "all", verbose = TRUE, ..
   }
 
   # all available options...
-  all_metrics <- c("AIC", "BIC", "R2", "R2_adj", "RMSE", "SIGMA", "LOGLOSS", "PCP", "SCORE")
+  all_metrics <- c(
+    "AIC",
+    "BIC",
+    "R2",
+    "R2_adj",
+    "RMSE",
+    "SIGMA",
+    "LOGLOSS",
+    "PCP",
+    "SCORE"
+  )
 
   if (all(metrics == "all")) {
     metrics <- all_metrics
@@ -16,12 +25,15 @@ model_performance.default <- function(model, metrics = "all", verbose = TRUE, ..
     metrics <- c("AIC", "BIC", "R2", "R2_adj", "RMSE")
   }
 
-  # check for valid input
   metrics <- .check_bad_metrics(metrics, all_metrics, verbose)
 
   if (!insight::is_model(model) || !insight::is_model_supported(model)) {
     if (isTRUE(verbose)) {
-      insight::format_warning(paste0("Objects of class `", class(model)[1], "` are not supported model objects."))
+      insight::format_warning(paste0(
+        "Objects of class `",
+        class(model)[1],
+        "` are not supported model objects."
+      ))
     }
     return(NULL)
   }
@@ -30,9 +42,7 @@ model_performance.default <- function(model, metrics = "all", verbose = TRUE, ..
 }
 
 
-
 .check_bad_metrics <- function(metrics, all_metrics, verbose = TRUE) {
-  # check for valid input
   bad_metrics <- which(!metrics %in% all_metrics)
   if (length(bad_metrics)) {
     if (verbose) {
