@@ -1,3 +1,35 @@
+#' @rdname display.performance_model
+#' @export
+print.performance_model <- function(x, digits = 3, layout = "horizontal", ...) {
+  layout <- insight::validate_argument(
+    layout,
+    c("horizontal", "vertical")
+  )
+  formatted_table <- format(x = x, digits = digits, format = "text", ...)
+
+  # switch to vertical layout
+  if (layout == "vertical") {
+    formatted_table <- datawizard::rownames_as_column(
+      as.data.frame(t(formatted_table)),
+      "Metric"
+    )
+    colnames(formatted_table)[2] <- "Value"
+  }
+
+  cat(
+    insight::export_table(
+      x = formatted_table,
+      digits = digits,
+      format = "text",
+      caption = c("# Indices of model performance", "blue"),
+      ...
+    )
+  )
+
+  invisible(x)
+}
+
+
 #' @export
 print.r2_generic <- function(x, digits = 3, ...) {
   model_type <- attr(x, "model_type")
@@ -27,13 +59,25 @@ print.r2_generic <- function(x, digits = 3, ...) {
     out[1] <- .add_r2_ci_to_print(out[1], x$R2[2], x$R2[3], digits = digits)
   }
   if (!is.null(x$R2_adjusted) && length(x$R2_adjusted) == 3 && length(out) > 1) {
-    out[2] <- .add_r2_ci_to_print(out[2], x$R2_adjusted[2], x$R2_adjusted[3], digits = digits)
+    out[2] <- .add_r2_ci_to_print(
+      out[2],
+      x$R2_adjusted[2],
+      x$R2_adjusted[3],
+      digits = digits
+    )
   }
   if (!is.null(x$R2_within) && length(x$R2_within) == 3 && length(out) > 2) {
     out[3] <- .add_r2_ci_to_print(out[3], x$R2_within[2], x$R2_within[3], digits = digits)
   }
-  if (!is.null(x$R2_within_adjusted) && length(x$R2_within_adjusted) == 3 && length(out) > 3) {
-    out[4] <- .add_r2_ci_to_print(out[4], x$R2_within_adjusted[2], x$R2_within_adjusted[3], digits = digits)
+  if (
+    !is.null(x$R2_within_adjusted) && length(x$R2_within_adjusted) == 3 && length(out) > 3
+  ) {
+    out[4] <- .add_r2_ci_to_print(
+      out[4],
+      x$R2_within_adjusted[2],
+      x$R2_within_adjusted[3],
+      digits = digits
+    )
   }
 
   # separate lines for multiple R2
@@ -123,10 +167,18 @@ print.r2_bayes <- function(x, digits = 3, ...) {
       ci = attributes(x)$CI$R2_Bayes_marginal$CI,
       digits = digits
     )
-    out <- paste(c(
-      out,
-      sprintf("     Marginal R2: %.*f (%s)", digits, x$R2_Bayes_marginal, r2_marginal_ci)
-    ), collapse = "\n")
+    out <- paste(
+      c(
+        out,
+        sprintf(
+          "     Marginal R2: %.*f (%s)",
+          digits,
+          x$R2_Bayes_marginal,
+          r2_marginal_ci
+        )
+      ),
+      collapse = "\n"
+    )
   }
 
   cat(out)
@@ -154,10 +206,13 @@ print.r2_loo <- function(x, digits = 3, ...) {
       ci = attributes(x)$CI$R2_loo_marginal$CI,
       digits = digits
     )
-    out <- paste(c(
-      out,
-      sprintf("     Marginal R2: %.*f (%s)", digits, x$R2_loo_marginal, r2_marginal_ci)
-    ), collapse = "\n")
+    out <- paste(
+      c(
+        out,
+        sprintf("     Marginal R2: %.*f (%s)", digits, x$R2_loo_marginal, r2_marginal_ci)
+      ),
+      collapse = "\n"
+    )
   }
 
   cat(out)
@@ -173,3 +228,14 @@ print.r2_nakagawa_by_group <- function(x, digits = 3, ...) {
   cat("\n")
   invisible(x)
 }
+
+
+# we allow exporting HTML format based on "gt" or "tinytable"
+.check_format_backend <- function(...) {
+  dots <- list(...)
+  if (identical(dots$backend, "tt")) {
+    "tt"
+  } else {
+    "html"
+  }
+}
