@@ -8,7 +8,7 @@
 #' @return A named vector with the R2 value.
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' if (require("correlation") && require("Hmisc")) {
 #'   model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
 #'   r2_somers(model)
@@ -23,7 +23,7 @@ r2_somers <- function(model) {
 
   info <- insight::model_info(model, verbose = FALSE)
   if (!info$is_binomial) {
-    stop("'r2_somers()' only accepts logistic regression models.", call. = FALSE)
+    insight::format_error("`r2_somers()` only accepts logistic regression models.")
   }
 
   input <- data.frame(
