@@ -1,5 +1,4 @@
 skip_on_os("linux")
-skip_on_os("solaris")
 
 test_that("test_wald - lm", {
   m1 <- lm(Sepal.Length ~ Petal.Width * Species, data = iris)
@@ -13,8 +12,10 @@ test_that("test_wald - lm", {
   expect_equal(rez$p, ref$`Pr(>F)`, tolerance = 1e-4)
 
   # setting test = "LRT" is not expected, but should at least not fail
-  expect_warning(rez <- test_wald(m1, m2, test = "LRT"))
-  expect_equal(rez$Name, c("..1", "..2"))
+  expect_warning({
+    rez <- test_wald(m1, m2, test = "LRT")
+  })
+  expect_identical(rez$Name, c("..1", "..2"))
 
   # Reversed
   m3 <- m1
@@ -32,7 +33,9 @@ test_that("test_wald - glm", {
   m2 <- glm(vs ~ disp + hp, data = mtcars, family = "binomial")
   m3 <- glm(vs ~ disp, data = mtcars, family = "binomial")
 
-  expect_warning(rez <- test_wald(m1, m2, m3))
+  expect_message({
+    rez <- test_wald(m1, m2, m3)
+  })
   ref <- as.data.frame(anova(m1, m2, m3, test = "LRT"))
 
   expect_equal(rez$Chi2, abs(ref$Deviance), tolerance = 1e-4)
